@@ -1,4 +1,4 @@
-/* Copyright 2008,2009,2010,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/* Copyright 2008,2009,2010,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -171,6 +171,12 @@ public:
 	 * This handles different length of the id string.
 	 */
 	bool compareId(const QString &other) const;
+
+	/**
+	 * @brief return if this key can be used for encryption
+	 */
+	bool canEncrypt() const;
+
 Q_SIGNALS:
 	void expanded();
 
